@@ -18,10 +18,7 @@ from blockdiag.elements import *
 
 
 class DiagramNode(blockdiag.elements.DiagramNode):
-    def __init__(self, id):
-        super(DiagramNode, self).__init__(id)
-
-        self.lane = None
+    lane = None
 
 
 class NodeGroup(blockdiag.elements.NodeGroup):
